#
# spec file for package clhep
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define tagname 2_4_7_1
%define shlib libCLHEP-%{tagname}
%define _ver %(echo %{tagname} | tr '_' '.')
# clhep requires a buildir which is not a subdirectory of the sourcedir
%global __builddir %{_builddir}/%{name}_build

Name:           clhep
Version:        2.4.7.1
Release:        2.5
Summary:        A class library for high energy physics
License:        GPL-3.0-only OR LGPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://proj-clhep.web.cern.ch/proj-clhep/
Source0:        https://gitlab.cern.ch/CLHEP/CLHEP/-/archive/CLHEP_%{tagname}/CLHEP-CLHEP_%{tagname}.tar.bz2#/clhep-%{tagname}.tar.bz2
# PATCH-FIX-UPSTREAM clhep-respect-build_static_libs.patch badshah400@gmail.com -- Don't build or install static libs if BUILD_STATIC_LIBS is OFF
Source99:       clhep.macros
Patch1:         clhep-respect-build_static_libs.patch
# PATCH-FIX-UPSTREAM clhep-docdir.patch badshah400@gmail.com -- Allow configuring docdir from cmake command
Patch2:         clhep-docdir.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
# Section Docs
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  texlive-latex-bin
# /Section
%include %SOURCE99

%description
CLHEP is intended to be a set of high energy physics specific
foundation and utility classes such as random generators, physics
vectors, geometry and linear algebra. CLHEP is structured in a set of
packages independent of any external package (interdependencies within
CLHEP are allowed under certain conditions).

%package -n %{shlib}
Summary:        A class library for high energy physics
Group:          Productivity/Scientific/Physics
Provides:       clhep = %{version}
Obsoletes:      clhep < %{version}

%description -n %{shlib}
CLHEP is intended to be a set of high energy physics specific
foundation and utility classes such as random generators, physics
vectors, geometry and linear algebra. CLHEP is structured in a set of
packages independent of any external package (interdependencies within
CLHEP are allowed under certain conditions).

This package provides the shared libraries for CLHEP.

%package devel
Summary:        A class library for high energy physics
Group:          Development/Libraries/C and C++
Requires:       %{name}-Units-devel = %{version}
Requires:       %{name}-Utility-devel = %{version}
Requires:       %{shlib} = %{version}
Requires:       pkgconfig(clhep-cast) = %{version}
Requires:       pkgconfig(clhep-evaluator) = %{version}
Requires:       pkgconfig(clhep-exceptions) = %{version}
Requires:       pkgconfig(clhep-genericfunctions) = %{version}
Requires:       pkgconfig(clhep-geometry) = %{version}
Requires:       pkgconfig(clhep-matrix) = %{version}
Requires:       pkgconfig(clhep-random) = %{version}
Requires:       pkgconfig(clhep-randomobjects) = %{version}
Requires:       pkgconfig(clhep-refcount) = %{version}
Requires:       pkgconfig(clhep-vector) = %{version}
Recommends:     %{name}-doc = %{version}

%description devel
CLHEP is intended to be a set of high energy physics specific
foundation and utility classes such as random generators, physics
vectors, geometry and linear algebra. CLHEP is structured in a set of
packages independent of any external package (interdependencies within
CLHEP are allowed under certain conditions).

This package provides the header files and libraries for development
of applications using CLHEP.

%package doc
Summary:        Documentation for CLHEP
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package provides documentation for the CLHEP library.

# Section CLHEP library subpackages

%package Units-devel
Summary:        The Units library from CLHEP
BuildArch:      noarch

%description Units-devel
This package provides the header-only Units library from CLHEP

%package Utility-devel
Summary:        CLHEP Utility library
BuildArch:      noarch

%description Utility-devel
This package provides the header-only Utility library from CLHEP.

%clhep_subpkg_lib -n Cast
%clhep_subpkg_lib -n Evaluator
%clhep_subpkg_lib -n Exceptions
%clhep_subpkg_lib -n GenericFunctions
%clhep_subpkg_lib -n Geometry
%clhep_subpkg_lib -n Matrix
%clhep_subpkg_lib -n Random
%clhep_subpkg_lib -n RandomObjects
%clhep_subpkg_lib -n RefCount
%clhep_subpkg_lib -n Vector

# Note pkgconfig based requires are automatically determined
%clhep_subpkg_devel -n Cast
%clhep_subpkg_devel -n Evaluator
%clhep_subpkg_devel -n Exceptions
%clhep_subpkg_devel -n GenericFunctions
%clhep_subpkg_devel -n Geometry
%clhep_subpkg_devel -n Matrix clhep-Units-devel clhep-Utility-devel
%clhep_subpkg_devel -n Random clhep-Units-devel clhep-Utility-devel
%clhep_subpkg_devel -n RandomObjects clhep-Units-devel clhep-Utility-devel
%clhep_subpkg_devel -n RefCount
%clhep_subpkg_devel -n Vector clhep-Units-devel

# /Section
%prep
%autosetup -n CLHEP-CLHEP_%{tagname} -p1
chmod -x README.md ChangeLog

%build
# remove nonworking check for LIB_SUFFIX, gives wrong result for PPC64
sed -i "/_clhep_lib_suffix_64()/d" cmake/Modules/ClhepVariables.cmake

%cmake \
  -DCLHEP_BUILD_DOCS:BOOL=ON \
  -DCLHEP_DOCDIR:PATH=%{_docdir}/%{name}/ \
%ifarch x86_64 ppc64 ppc64le aarch64 riscv64
  -DLIB_SUFFIX=64 \
%endif
%{nil}

%cmake_build

%install
%cmake_install

# testThreaded fails on 32-bit
%ifnarch %{ix86}
%check
%ctest
%endif

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%license COPYING COPYING.LESSER
%doc ChangeLog README.md
%{_libdir}/libCLHEP-%{version}.so

%files devel
%{_bindir}/clhep-config
%{_includedir}/CLHEP/*.h
%{_includedir}/clhep.modulemap
%{_libdir}/libCLHEP.so
%{_libdir}/CLHEP-%{version}/
%{_libdir}/pkgconfig/clhep.pc

%files doc
%{_docdir}/%{name}/

%files Units-devel
%{_bindir}/Units-config
%{_includedir}/CLHEP/Units/

%files Utility-devel
%{_bindir}/Utility-config
%{_includedir}/CLHEP/Utility/

%changelog
* Sun Jan  7 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add BuildRequires: graphviz for dot, needed by doxygen when
  generating docs.
* Fri Jan  5 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Split out complex helper macros into clhep.macros.
* Sun Dec 17 2023 Atri Bhattacharya <badshah400@gmail.com>
- Split out individual subpackages for different CLHEP libraries,
  in keeping with dependency chart here:
  https://proj-clhep.web.cern.ch/proj-clhep/packages.html.
  * clhep-devel now drags in all the clhep-*-devel subpackages.
- Add clhep-docdir.patch to get documentation to install to a
  user configurable dir.
- Split out doc package and install doxygen generated HTML
  documentation to it; add as Recommends to clhep-devel.
* Thu Oct 12 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.6.7.1:
  * Random: add missing shootArray implementations
  * Random: mixmax_skip_N8.icc and mixmax_skip_N240.icc were
    removed as no longer necessary
- Run tests as part of %%check.
* Sat Sep 30 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.6.7.0:
  * Random: MIXMAX update for performance
* Mon Apr 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.6.4:
  * Add support for -std=c++20 and -std=c++2a.
* Mon Jan  2 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.6.3:
  * Fix compilation warnings on XCode 14.1 for implicit type
    conversions.
- Changes from version 2.4.6.2:
  * Evaluator/test/testEvaluator.output: match change in e_SI.
- Changes from version 2.4.6.1:
  * Evaluator/src/setSystemOfUnits.cc: update units to match
    Units/SystemOfUnits.h.
  * Random: add the cstdint header where uint32_t and uint64_t are
    used.
* Wed Nov  9 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.6.0:
  * Evaluator: Resolve worrying GCC 12 warnings
  * Random: Resolve worrying GCC 12 warnings
- Drop no longer needed clhep-rpmlintrc file.
- Minor offset changes to clhep-respect-build_static_libs.patch.
* Fri Sep 30 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.4.5.3:
  For details, see include ChangeLog or
  https://gitlab.cern.ch/CLHEP/CLHEP/-/blob/CLHEP_2_4_5_3/ChangeLog
- Drop obsolete clhep-randomobjects-pkgconfig-requires.patch
* Sun Apr  5 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.4.1.3:
  * Vector/Vector/*.h: added move constructor and move assignment.
  * Geometry/Geometry/*.h: added move constructor and move
    assignment.
- Changes from previous versions: See ChangeLog file.
- Drop clhep-thread_local-header-location.patch: incorporated
  upstream.
- Use cmake macros for configuring, building, and installing.
- Use %%license to install license file.
- Update Source URL.
- Add clhep-randomobjects-pkgconfig-requires.patch to remove a
  spurious '=' sign copied into clhep-randomobjects.pc pkgconfig
  file.
- Add clhep-respect-build_static_libs.patch: Don't install static
  libs and don't refer to them in installed cmake scripts if
  BUILD_STATIC_LIBS is turned OFF; drop static libs package.
* Sun Nov 20 2016 badshah400@gmail.com
- Add clhep-thread_local-header-location.patch to fix dir of
  thread_local.h -- it should be installed in Utility/, not inside
  Utility/thread_local.h/; patch sent upstream.
* Sun Nov 20 2016 badshah400@gmail.com
- Update to version 2.3.4.0:
  * cmake: Add the ability to build single threaded if desired.
    Multihreading remains enabled by default.
    Use cmake -DCLHEP_SINGLE_THREAD=ON to disable multithreading.
  * Utility/thread_local.h will be generated appropriately
  * Random/Random/mixmax.h: corrected value of SPECIALMUL in
    mixmax.h to correspond to exact formula for N=17 (m=2^36+1).
  * Evaluator/src/Evaluator.cc: fixed array initialisation in
    Evaluator static method function().
- Changes from previous versions: see ChangeLog file or
  https://gitlab.cern.ch/CLHEP/CLHEP/blob/CLHEP_2_3_3_2/ChangeLog.
- CMake > 3.2 is now really required (since v2.3.3.0).
- Update License tag for LGPL-3.0 license.
* Sat Nov 19 2016 badshah400@gmail.com
- Apply shared library packaging policy guidelines:
  * Rename clhep to libCLHEP-2_3_2_2 (define a %%{shalib} macro)
    for the purpose.
  * Split out static library into a -devel-static package.
- Add rpmlintrc file to suppress false positives and complaints
  regarding missing manuals. The shared libs are named according
  to package number and there is no so number associated with
  them, which causes rpmlintrc to give the shared lib warnings.
  For the warning about missing man pages, nothing much we can do.
- Add BuildRequires: pkgconfig to make sure the devel package
  provides the right pkgconfig() provides; fixes an rpmlintrc
  complaint.
* Wed May 18 2016 bugs@vdm-design.de
- Downgrade required CMake version to 2.8 as 3.2 is not really required
* Wed May 18 2016 bugs@vdm-design.de
- Update to version 2.3.2.2
- Change from automake to cmake
* Sat Jan 30 2016 bugs@vdm-design.de
- Run ldconfig in post install of clhep and not clhep-devel
* Sat Mar 28 2015 bugs@vdm-design.de
- Update to version 2.2.0.5
  * Only build system changes
* Fri Dec 26 2014 bugs@vdm-design.de
- Update to version 2.2.0.4
  * Utility/Utility/memory.h: fix a type mismatch
  * GenericFunctions/src/DefiniteIntegral.cc: explicit initialization
  * Random/src/RanshiEngine.cc: use a pragma to ignore aggressive 32bit compiler warnings
  * Vector/Vector/ThreeVector.icc: inline Hep3Vector::operator () (int i)
* Fri Sep 12 2014 bugs@vdm-design.de
- Update to version 2.2.0.3
  * cmake/Modules/ClhepVariables.cmake: DO NOT use any -ftls-model flags.
    Except in very specialized cases, the compiler automatically does the right thing.
* Wed Aug 13 2014 bugs@vdm-design.de
- Update to version 2.2.0.2
  * Units/Units/SystemOfUnits.h, Units/Units/PhysicalConstants.h:
    move definition of pi into SystemOfUnits so it is not defined twice
    Note that PhysicalConstants.h includes SystemOfUnits.h.
* Tue Jun 24 2014 bugs@vdm-design.de
- Update to version 2.2.0.1
  * Geometry/test/testBasicVector3D.cc: pragma fix for modern clang
  * GenericFunctions/GenericFunctions/StepDoublingRKStepper.hh: fix wrapper name
  * Random/src/RanshiEngine.cc: use explicit 32bit mask to avoid compiler warnings
  * Random/src/MTwistEngine.cc: make sure we don't go past the end of the
    array in MTwistEngine::showStatus
  * Random/src/Random.cc: remove unnecessary inline
  * In Random package convert statics and globals to const, thread
    local or atomic to improve thread safety.
* Wed May 14 2014 bugs@vdm-design.de
- Update to version 2.1.4.2
  * bug http://savannah.cern.ch/bugs/?104289
  * Vector, Random, Matrix: remove register declaration of ints and doubles
    use of register is now redundant and ignored by modern compilers
  * GenericFunctions, Geometry/test, Utility/test, Vector/test:
    protect against warnings about variables that are used inside asserts
* Mon Nov 18 2013 bugs@vdm-design.de
- Update to version 2.1.4.1
  * Random: including RandExpZiggurat and RandGaussZiggurat
  * Matrix: change the names of more internal variables so -Wshadow does not complain
  * Units/Units/SystemOfUnits.h: adding definitions for curies
  * configure.ac: change for unsupported Darwin build with autotools
* Thu Nov 15 2012 bugs@vdm-design.de
- Update to version 2.1.3.1
  * Vector: clean up naming overlap between Units and internal variables
* Fri Nov  9 2012 bugs@vdm-design.de
- Update to version 2.1.3.0
  * creation of symbolic links now respects DESTDIR
  * MATRIX/DiagMatrix, MATRIX/GenMatrix, MATRIX/SymMatrix:
    Added two methods to [-,Diag,Sym]Matrix to carry out the matrix
    inversion without the users needing to provide an ierr flag.
    These methods are all inline and called invert() and inverse(),
    so they overload the existing inversion routines for the relevant class.
    If an error occurs, then an std::runtime_error is thrown.
  * clhep-config: fix for Mountain Lion
* Fri Aug 17 2012 bugs@vdm-design.de
- Update to version 2.1.2.5
  * GenericFunctions: latest changes from Joe Boudreau
  * GenericFunctions: change the names of internal variables so -Wshadow does not complain
  * cmake/Modules: use OUTPUT_STRIP_TRAILING_WHITESPACE with execute_process commands
  * CMakeLists.txt, cmake/Modules: enable -DLIB_SUFFIX=64
  * Vector/LorentzVector.h: make the HepLorentzVector(double t) constructor explicit
* Thu Jul 12 2012 bugs@vdm-design.de
- Update to version 2.1.2.4
- Changes since 2.1.2.2
  * cmake/Modules: enclose CMAKE_COMMAND in quotes when inside execute_process
  * test shell scripts: make sure any paths are enclosed in quotes
  * cmake/Modules: Use newer execute_process instead of exec_program
    Try to cope with special characters in path
  * Random: fix for shadowing when global units used
  * Vector: fix for shadowing when global units used
    USING_VISUAL code blocks are no longer needed
  * GenericFunctions: latest changes from Joe Boudreau
  * Matrix: cleanup for -Wextra
  * Vector, Evaluator, Random, Geometry: use explicit std:: with math functions
* Wed May 16 2012 badshah400@gmail.com
- Update to version 2.1.2.2:
  + Make sure config files are executable add
    clhep_package_config_no_lib()
- Changes since previosuly packaged version 2.1.0.1:
  + Too many: see ChangeLog file packaged in
    /usr/share/doc/packages/clhep
- Use upstream compressed tarball now
- Do not use cmake for building though it is the recommended way
  to install according to upstream because the cmake build system
  does not allow setting the library directory easily leading to
  libraries being installed in /usr/lib even for x86_64 builds.
* Sun Feb 26 2012 scorot@free.fr
- fix build for SLE-11
* Sat Nov 19 2011 werner.ho@gmx.de
- updated to version 2.1.1.0
* Sun Apr 24 2011 badshah400@gmail.com
- Initial package (version 2.1.0.1)
